@@ -1,5 +1,5 @@
 """
-migrado database client
+Migrado database client
 
 Copyright © 2019 Protojour AS, licensed under MIT.
 See LICENSE.txt for details.
@@ -8,7 +8,7 @@ See LICENSE.txt for details.
 import subprocess
 
 from arango import ArangoClient
-from arango.exceptions import *
+from arango.exceptions import TransactionExecuteError
 
 
 class MigrationClient:
@@ -43,13 +43,19 @@ class MigrationClient:
         if self.db.has_collection(self.coll_name) and self.state_coll.has('state'):
             state = self.state_coll.get('state')
         else:
-            state = {
-                '_key': 'state',
-                'migration_id': '0000',
-            }
+            state = {'migration_id': '0000'}
 
         return state.get('migration_id')
 
+    def read_schema(self):
+        """Read schema from state collection"""
+        if self.db.has_collection(self.coll_name) and self.state_coll.has('schema'):
+            state = self.state_coll.get('schema')
+        else:
+            state = {'schema': {}}
+
+        return state.get('schema')
+
     def write_state(self, migration_id):
         """Write given state to state collection"""
         state = {
@@ -58,8 +64,56 @@ class MigrationClient:
         }
         return self.state_coll.insert(state, overwrite=True, silent=True)
 
+    def write_schema(self, schema):
+        """Write given schema to state collection"""
+        state = {
+            '_key': 'schema',
+            'schema': schema,
+        }
+        return self.state_coll.insert(state, overwrite=True, silent=True)
+
+    def infer_schema(self, validation):
+        """Infer schema from current database structure"""
+        schema = {
+            'collections': {},
+            'edge_collections': {},
+        }
+
+        collections = self.db.collections()
+        db_collections = [
+            collection['name'] for collection in collections
+            if (collection['type'] == 'document'
+                and not collection['system']
+                and not collection['name'] == self.coll_name)
+        ]
+        db_edge_collections = [
+            collection['name'] for collection in collections
+            if (collection['type'] == 'edge'
+                and not collection['system'])
+        ]
+
+        for collection in db_collections:
+            schema['collections'][collection] = None
+            if validation:
+                props = self.db.collection(collection).properties()
+                collection_schema = props.get('schema')
+                if collection_schema:
+                    schema['collections'][collection] = {}
+                    schema['collections'][collection]['schema'] = collection_schema
+
+        for collection in db_edge_collections:
+            schema['edge_collections'][collection] = None
+            if validation:
+                props = self.db.collection(collection).properties()
+                collection_schema = props.get('schema')
+                if collection_schema:
+                    schema['edge_collections'][collection] = {}
+                    schema['edge_collections'][collection]['schema'] = collection_schema
+
+        return schema
+
     def run_transaction(self, script, write_collections,
-                        max_transaction_size=None, intermediate_commit_size=None, intermediate_commit_count=None):
+            max_transaction_size=None, intermediate_commit_size=None, intermediate_commit_count=None):
         """Execute JavaScript command in transaction against ArangoDB"""
         try:
             return self.db.execute_transaction(
@@ -83,7 +137,7 @@ class MigrationClient:
         ]
         if self.username and self.password:
             command += [
-                '--server.authentication', 'true'
+                '--server.authentication', 'true',
                 '--server.username', self.username,
                 '--server.password', self.password,
             ]
